@@ -1,4 +1,4 @@
 from .on_policy_actor_critic import OnPolicyActorCritic
 from .off_policy_actor_critic import OffPolicyActorCritic
-from .neural_networks.feature_extractors import get_model
+from .neural_networks.feature_extractors import get_feature_extractor
 
