@@ -18,9 +18,6 @@ class OnPolicyBuffer(S):
 
     Attributes
     ----------
-    on_policy_data_fields : tuple
-        Accepted data fields. If the samples inserted contain other fields,
-        an AssertionError will be raised.
     max_size : int
         Storage capacity along time axis.
     device: torch.device
@@ -28,6 +25,7 @@ class OnPolicyBuffer(S):
         computations will take place.
     """
 
+    # Accepted data fields. Inserting other fields will raise AssertionError
     on_policy_data_fields = ("obs", "obs2", "rhs", "act", "rew", "val", "logp", "done")
 
     def __init__(self, size, device=torch.device("cpu")):
