@@ -10,13 +10,16 @@ def cleanup_log_dir(log_dir):
     log_dir : str
         Path to log directory.
     """
+    os.makedirs(log_dir, exist_ok=True)
+
     try:
-        os.makedirs(log_dir)
-    except OSError:
         if os.path.isdir(os.path.join(log_dir, "train")):
             shutil.rmtree(os.path.join(log_dir, "train"))
         if os.path.isdir(os.path.join(log_dir, "test")):
             shutil.rmtree(os.path.join(log_dir, "test"))
         if os.path.isdir(os.path.join(log_dir, "tensorboard_logs")):
             shutil.rmtree(os.path.join(log_dir, "tensorboard_logs"))
+    except Exception:
+        print("Unable to cleanup log_dir...")
+
 
